/* Copyright (c) 2009 Nordic Semiconductor. All Rights Reserved.
 *
 * The information contained herein is property of Nordic Semiconductor ASA.
 * Terms and conditions of usage are described in detail in NORDIC
 * SEMICONDUCTOR STANDARD SOFTWARE LICENSE AGREEMENT.
 *
 * Licensees are granted free, non-transferable use of the information. NO
 * WARRANTY of ANY KIND is provided. This heading must NOT be removed from
 * the file.
 *
 */

/** @file
 * @brief Pin change interrupt example
 * @defgroup pin_change_int_example Pin change usage example
 * @{
 * @ingroup nrf_examples_nrf6310
 *
 * @brief Pin change interrupt example
 *
 * This example demonstrates interrupt on pin change on pin 0. Pin8 is configured
 * as output and toggled in the pin change interrupt handler.
 *
 * @image html example_board_setup_a.png "Use board setup A for this example."
 */

#include <stdbool.h>
#include "nrf.h"
#include "nrf_gpio.h"
#include "nrf_delay.h"

#define MY_BUTTON 0
#define MY_LED    8

/**
 * Configures pin 0 for input and pin 8 for output and
 * configures GPIOTE to give interrupt on pin change.
 */
static void gpio_init(void)
{
  NRF_GPIO->PIN_CNF[MY_BUTTON] = (GPIO_PIN_CNF_SENSE_Low << GPIO_PIN_CNF_SENSE_Pos)
                                        | (GPIO_PIN_CNF_DRIVE_S0S1 << GPIO_PIN_CNF_DRIVE_Pos)
                                        | (NRF_GPIO_PIN_NOPULL << GPIO_PIN_CNF_PULL_Pos)
                                        | (GPIO_PIN_CNF_INPUT_Connect << GPIO_PIN_CNF_INPUT_Pos)
                                        | (GPIO_PIN_CNF_DIR_Input << GPIO_PIN_CNF_DIR_Pos);    
  nrf_gpio_cfg_output(MY_LED);

  nrf_gpio_pin_write(MY_LED, 0);

  // Enable interrupt:
  NVIC_EnableIRQ(GPIOTE_IRQn);
  NRF_GPIOTE->INTENSET = GPIOTE_INTENSET_PORT_Set << GPIOTE_INTENSET_PORT_Pos;
}

/** GPIOTE interrupt handler.
 * Triggered on pin 0 change
 */
void GPIOTE_IRQHandler(void)
{
  // Event causing the interrupt must be cleared
  if ((NRF_GPIOTE->EVENTS_PORT != 0))
  {
    NRF_GPIOTE->EVENTS_PORT = 0;
  }
  // Active low.
  if (nrf_gpio_pin_read(MY_BUTTON) == 0)
  {
      nrf_gpio_pin_toggle(MY_LED);
  }
}

/**
 * main function
 * \return 0. int return type required by ANSI/ISO standard.
 */
int main(void)
{
  gpio_init();  
  while (true)
  {
  }
}

/**
 *@}
 **/
